@@ -75,13 +75,15 @@
 2023.1.8 1.1.9.4版本
     --- 感谢! PyQt5学习爱好群-(讨厌自己)修复 PyQt6 版本下 无边框类(Borderless)移动BUG
     --- 增加 内置-样式设计器,主要是为了配合皮肤包
+2023.1.9 1.1.9.5版本
+    --- 标题栏和状态栏 终于 不用主窗口中重写 resizeEvent事件来调用 updateXXX() 来完成大小自适应了
+    --- 修复了 内置-样式设计器 不少BUG
 '''
 
 # ===============================================
 
 '''
 记录已知BUG,但是还未修复
-PyQt6 版本下 无边框类(Borderless)移动有BuG
 轮播组件(SlideShow) 后期将重写
 
 '''
\ No newline at end of file
