@@ -1,5 +1,5 @@
 import sys
-from PyQt5.QtWidgets import QWidget,QApplication,QPushButton,QHBoxLayout
+from PyQt5.QtWidgets import QWidget,QApplication,QPushButton,QHBoxLayout,QTableWidget
 
 
 class Test(QWidget):
